---
title: DASCore Development Installation
---

The following steps are needed to set up `DASCore` for development:

## 1. Clone DASCore

```bash
git clone https://github.com/dasdae/dascore
cd dascore
```

## 2. Pull tags

Make sure to pull all of the latest git tags.


```bash
git pull origin master --tags
```

## 3. Create a virtual environment (optional)

Create and activate a virtual environment so DASCore will not mess with the base (or system) python installation.

If you are using [Anaconda](https://www.anaconda.com/), simply use the environment provided:

```bash
conda env create -f environment.yml
conda activate dascore
```

## 4. Install DASCore in development mode

```bash
pip install -e ".[dev]"
```

## 5. Setup pre-commit hooks

dascore uses several [pre-commit](https://pre-commit.com/) hooks to ensure the code stays tidy. Please install and use them!

```bash
pre-commit install -f
```

# Refresh

If you have already installed dascore but it has been a while, please do the following before creating a new branch:

```bash
git checkout master
git pull origin master --tags
pip install -e ".[dev]"
```

The first line ensures you are on the master branch, the second line will pull the latest changes and tags, and the last line
will install again in developer mode. This is only required if DASCore's entry points or requirements have changed, but
won't hurt anything if not.
